Node Item (nodeitem) — Orange Canvas Core 0.0.9 documentation

# Orange Canvas Core 0.0.9 documentation

## Node Item (nodeitem)

# Node Item (`nodeitem`)

## Node Item

class `orangecanvas.canvas.items.nodeitem.` `NodeItem`(widget_description=None, parent=None, **kwargs)

  Bases: `PyQt5.QtWidgets.QGraphicsObject`

  An widget node item in the canvas.

  `positionChanged`
  `anchorGeometryChanged`
  `activated`
  `anchorRotation`()

    Return the anchor rotation.

  `animationEnabled`()

    Are node animations enabled.

  `font`()

    Return the title text font.

  `inputAnchors`()

    Return a list of all input anchor points.

  `newInputAnchor`()

    Create and return a new input `AnchorPoint`.

  `newOutputAnchor`()

    Create and return a new output `AnchorPoint`.

  `outputAnchors`()

    Return a list of all output anchor points.

  `processingState`()

    The node processing state.

  `processingState_`

    The node processing state.

  `progress`()

    Return the node work progress state.

  `progress_`

    Node progress state.

  `removeInputAnchor`(anchor)

    Remove input anchor.

  `removeOutputAnchor`(anchor)

    Remove output anchor.

  `setAnchorRotation`(angle)

    Set the anchor rotation.

  `setAnimationEnabled`(enabled)

    Set the node animation enabled state.

  `setColor`(color, selectedColor=None)

    Set the widget color.

  `setFont`(font)

    Set the title text font (`QFont`).

  `setIcon`(icon)

    Set the node item’s icon (`QIcon`).

  `setProcessingState`(state)

    Set the node processing state i.e. the node is processing (is busy) or is idle.

  `setProgress`(progress)

    Set the node work progress state (number between 0 and 100).

  `setStateMessage`(message)

    Set a state message to display over the item.

    Parameters: | message (UserMessage) – Message to display. message.severity is used to determine the icon and message.contents is used as a tool tip.

  `setStatusMessage`(message)

    Set the node status message text.

    This text is displayed below the node’s title.

  `setTitle`(title)

    Set the node title. The title text is displayed at the bottom of the node.

  `setWidgetCategory`(desc)

    Set the widget category.

  `setWidgetDescription`(desc)

    Set widget description.

  `title`()

    Return the node title.

  `title_`

    Node title text.

class `orangecanvas.canvas.items.nodeitem.` `AnchorPoint`(*args)

  Bases: `PyQt5.QtWidgets.QGraphicsObject`

  A anchor indicator on the `NodeAnchorItem`.

  `scenePositionChanged`(QPointF)
  `anchorDirectionChanged`(QPointF)
  `anchorDirection`()

    Return the preferred anchor direction.

  `anchorScenePos`()

    Return anchor position in scene coordinates.

  `setAnchorDirection`(direction)

    Set the preferred direction (QPointF) in item coordinates.